API Reference
#############

.. doxygenclass:: nurex::DensityType
   :members:

.. doxygenclass:: nurex::Nucleus 
   :members:

.. doxygenclass:: nurex::NNCrossSectionFit
   :members:

.. doxygenclass:: nurex::GlauberModel
   :members:



